import configargparse


def parse() -> configargparse.Namespace:
    p = configargparse.ArgParser()
    p.add('-c', '--config', required=False, is_config_file=True, help='config file path')
    p.add('--host', action='append', default=[], help='remote host address, simulate training if not set')
    p.add('--ca-cert', default='', help='CA cert path')
    return p.parse_args()


if __name__ == '__main__':
    options = parse()
    print(options)



from . import configuration, connection
import typing

__version__ = '0.0.5'


def initialize():
    options = configuration.parse()
    hosts: typing.List[str] = options.host
    ca_cert_path: str = options.ca_cert
    if hosts:
        connection.set_grpc(hosts=hosts, ca_cert_path=ca_cert_path)
